summaryrefslogtreecommitdiffstats
path: root/kspread/kspread_sheet.h
diff options
context:
space:
mode:
Diffstat (limited to 'kspread/kspread_sheet.h')
-rw-r--r--kspread/kspread_sheet.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/kspread/kspread_sheet.h b/kspread/kspread_sheet.h
index 2947728c..ff6272ac 100644
--- a/kspread/kspread_sheet.h
+++ b/kspread/kspread_sheet.h
@@ -240,11 +240,11 @@ public:
Doc* doc() const;
/**
- * Saves the sheet and all it's tqchildren in XML format
+ * Saves the sheet and all it's children in XML format
*/
virtual TQDomElement saveXML( TQDomDocument& );
/**
- * Loads the sheet and all it's tqchildren in XML format
+ * Loads the sheet and all it's children in XML format
*/
virtual bool loadXML( const TQDomElement& );
@@ -259,12 +259,12 @@ public:
void saveOasisPrintStyleLayout( KoGenStyle &style ) const;
/**
- * Saves a tqchildren
+ * Saves a children
*/
virtual bool saveChildren( KoStore* _store, const TQString &_path );
bool saveOasisObjects( KoStore *store, KoXmlWriter &xmlWriter, KoGenStyles& mainStyles, int & indexObj, int &partIndexObj );
/**
- * Loads a tqchildren
+ * Loads a children
*/
virtual bool loadChildren( KoStore* _store );
@@ -991,9 +991,9 @@ public:
void autofill( TQRect &src, TQRect &dest );
- bool insertChild( const KoRect& _tqgeometry, KoDocumentEntry& );
+ bool insertChild( const KoRect& _geometry, KoDocumentEntry& );
- bool insertChart( const KoRect& _tqgeometry, KoDocumentEntry&, const TQRect& _data );
+ bool insertChart( const KoRect& _geometry, KoDocumentEntry&, const TQRect& _data );
/**
@@ -1016,7 +1016,7 @@ public:
*/
bool insertPicture( const KoPoint& point, const TQPixmap& pixmap );
- void changeChildGeometry( EmbeddedKOfficeObject *_child, const KoRect& _tqgeometry );
+ void changeChildGeometry( EmbeddedKOfficeObject *_child, const KoRect& _geometry );
const TQColorGroup& colorGroup() { return widget()->colorGroup(); }
@@ -1033,7 +1033,7 @@ public:
* Checks if the argument _column is out of the current maximum range of the vertical border
* If this is the case, the current maximum value m_iMaxColumn is adjusted and the vertical border
* is resized.
* Use this function with care, as it involves a tqrepaint of the border, when it is out of range.
*/
void checkRangeHBorder ( int _column );
@@ -1048,7 +1048,7 @@ public:
* Checks if the argument _row is out of the current maximum range of the horizontal border
* If this is the case, the current maximum value m_iMaxRow is adjusted and the horizontal border
* is resized.
* Use this function with care, as it involves a tqrepaint of the border, when it is out of range.
*/
void checkRangeVBorder ( int _row );
@@ -1102,7 +1102,7 @@ public:
*/
void refreshView(const Region& region);
- void emit_updateRow( RowFormat *_format, int _row, bool tqrepaint = true );
+ void emit_updateRow( RowFormat *_format, int _row, bool repaint = true );
void emit_updateColumn( ColumnFormat *_format, int _column );
/**
@@ -1033,7 +1033,7 @@ public:
* If this is the case, the current maximum value m_iMaxColumn is adjusted and the vertical border
* is resized.
- * Use this function with care, as it involves a tqrepaint of the border, when it is out of range.
+ * Use this function with care, as it involves a repaint of the border, when it is out of range.
*/
void checkRangeHBorder ( int _column );
@@ -1048,7 +1048,7 @@ public:
* If this is the case, the current maximum value m_iMaxRow is adjusted and the horizontal border
* is resized.
- * Use this function with care, as it involves a tqrepaint of the border, when it is out of range.
+ * Use this function with care, as it involves a repaint of the border, when it is out of range.
*/
void checkRangeVBorder ( int _row );